@@ -19,28 +19,6 @@ def _handle_auth_response(auth_response: Response, error_msg: str) -> dict:
         raise error
 
 
-def _sign_in_request_info(base_url: str, username: str, password: str):
-    return {
-        'url': f"{base_url}/login",
-        'data': json.dumps({"username": username, "password": password}),
-        'headers': {
-            "Accept": "application/json",
-            "Content-Type": "application/json"
-        }
-    }
-
-
-def _refresh_token_request_info(base_url: str, refresh_token: Optional[str] = None) -> dict:
-    return {
-        'url': f"{base_url}/refresh_token",
-        'data': json.dumps({"refresh_token": refresh_token}),
-        'headers': {
-            "Accept": "application/json",
-            "Content-Type": "application/json"
-        }
-    }
-
-
 def _access_token(access_token: str) -> dict:
     return json.loads(access_token)
 
